"""Generated types from JSON schemas — do not edit manually."""

from screencast_narrator_client.generated.config_types import (
    HighlightConfig as HighlightConfigGenerated,
    Model as ConfigModel,
    RecordingConfig,
)
from screencast_narrator_client.generated.storyboard_types import (
    HighlightStyle,
    Model as StoryboardModel,
    Narration,
    Options,
    ScreenAction,
    ScreenActionTiming,
    ScreenActionType,
)

__all__ = [
    "ConfigModel",
    "HighlightConfigGenerated",
    "HighlightStyle",
    "Narration",
    "Options",
    "RecordingConfig",
    "ScreenAction",
    "ScreenActionTiming",
    "ScreenActionType",
    "StoryboardModel",
]
